## Development

You can start a development environment with:

```shell
docker-compose up
```

Airflow needs to be restarted for your changes to take effect:

```shell
docker-compose restart airflow
```

## Testing

You can run the tests suite with:

```shell
./run_test.sh
```
